Calendar class final

A calendar system used to interpret dates.

Backed by the JS Temporal API. All Temporal types default to the ISO 8601 calendar unless an explicit Calendar is provided.

Constructors

Calendar(String id)
const

Properties

hashCode int
The hash code for this object.
no setteroverride
id String
The identifier string as defined by the Unicode CLDR calendar registry.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

buddhist → const Calendar
chinese → const Calendar
gregory → const Calendar
hebrew → const Calendar
islamic → const Calendar
iso → const Calendar
japanese → const Calendar
persian → const Calendar