TemporalException class
Thrown when a Temporal operation fails due to invalid input or out-of-range
values. kind contains the error category name from the TC39 spec
(e.g. 'range', 'type', 'syntax', 'generic').
- Implemented types
Constructors
- TemporalException(String kind)
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited